#!/bin/bash
#  This script is part of Numdiff
#  Copyright (C)  2005-2012    Ivano Primi  <ivprimi@libero.it>    
#
#   Copying and distribution of this file, with or without modification,
#   are permitted in any medium without royalty provided the copyright
#   notice and this notice are preserved.

LESS="less"
DIFF="diff"
#DIFF=/home/ivano/myprojs/numdiff/tests/Numdiff
NUMDIFF="numdiff"
#NUMDIFF="/home/ivano/myprojs/numdiff-5.2.0/numdiff"

echo "Viewer: $LESS"
echo "Tester program: $DIFF"
echo "Numdiff: $NUMDIFF"

TESTS="test1 test2 test4 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test21 test22 test24 test25 test26 test27 test28 test29 test30"

for TEST in $TESTS
do
  if [ $TEST == "test1" ]; then
      cd $TEST
  else
      cd ../$TEST
  fi
  echo -e "\nCurrent working directory: $PWD"
  RUNTEST="./run${TEST}b.sh"
  $RUNTEST $LESS $DIFF $NUMDIFF
done

